<?xml version="1.0" ?><!DOCTYPE TS><TS language="ru_RU" version="2.0">
<context>
    <name>TestPlugin</name>
    <message>
        <location filename="../testplugin.cpp" line="121"/>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <location filename="../testplugin.cpp" line="132"/>
        <source>Example Plugin Settings</source>
        <translation>Пример настроек расширения</translation>
    </message>
    <message>
        <location filename="../testplugin.cpp" line="160"/>
        <source>My first plugin action</source>
        <translation>Моё первое расширение</translation>
    </message>
    <message>
        <location filename="../testplugin.cpp" line="175"/>
        <source>Hello</source>
        <translation>Привет</translation>
    </message>
    <message>
        <location filename="../testplugin.cpp" line="175"/>
        <source>First plugin action works :-)</source>
        <translation>Первое расширение, которое работает:)</translation>
    </message>
</context>
<context>
    <name>TestPlugin_Sidebar</name>
    <message>
        <location filename="../testplugin_sidebar.cpp" line="32"/>
        <location filename="../testplugin_sidebar.cpp" line="37"/>
        <source>Testing Sidebar</source>
        <translation>Тестирование боковой панели</translation>
    </message>
</context>
</TS>